@@ -12,7 +12,10 @@
 #  See the License for the specific language governing permissions and
 #  limitations under the License.
 
-from .dlds_client import DLDSClient
-from .dlds_data_loader import DLDSDataLoader
+__version__ = '1.4.1'
 
-__version__ = '1.4.0'
+try:
+    from .dlds_client import DLDSClient
+    from .dlds_data_loader import DLDSDataLoader
+except ImportError:
+    pass
